@@ -6,7 +6,7 @@ from typing import List, TYPE_CHECKING, Type, Union, Any, Optional
 
 import pandas as pd
 from pydantic import BaseModel, ConfigDict
-from sqlalchemy import Engine, create_engine, insert, func
+from sqlalchemy import Engine, create_engine, insert
 from sqlmodel import Session, select
 from sqlmodel.main import SQLModel
 
@@ -28,6 +28,8 @@ from bearish.database.schemas import (
     PriceTrackerORM,
     FinancialsTrackerORM,
     IndexORM,
+    SecORM,
+    SecShareIncreaseORM,
 )
 from bearish.database.scripts.upgrade import upgrade
 from bearish.exchanges.exchanges import ExchangeQuery
@@ -49,6 +51,7 @@ from bearish.models.financials.metrics import (
     QuarterlyFinancialMetrics,
 )
 from bearish.models.price.price import Price
+from bearish.models.sec.sec import Sec, SecShareIncrease
 from bearish.utils.utils import batch
 
 if TYPE_CHECKING:
@@ -103,6 +106,22 @@ class BearishDb(BearishDbBase):
                 session.exec(stmt)  # type: ignore
             session.commit()
 
+    def _write_sec(self, secs: List["Sec"]) -> None:
+
+        with Session(self._engine) as session:
+            data = [sec.model_dump() for sec in secs]
+            chunks = batch(data, BATCH_SIZE)
+            for chunk in chunks:
+                stmt = insert(SecORM).prefix_with("OR REPLACE").values(chunk)
+                session.exec(stmt)  # type: ignore
+            session.commit()
+
+    def _read_sec(self, ticker: str) -> List[Sec]:
+        with Session(self._engine) as session:
+            stmt = select(SecORM).where(SecORM.ticker == ticker)
+            sources = session.exec(stmt).all()
+            return [Sec.model_validate(source.model_dump()) for source in sources]
+
     def _write_financials(self, financials: List[Financials]) -> None:
         many_financials = ManyFinancials(financials=financials)
         self._write_financials_series(
@@ -305,14 +324,7 @@ class BearishDb(BearishDbBase):
             query = select(tracker_orm.symbol, tracker_orm.exchange, tracker_orm.source)
             if tracker_query.exchange:
                 query = query.where(tracker_orm.exchange == tracker_query.exchange)
-            if tracker_query.reference_date:
-                query = query.where(
-                    func.abs(
-                        func.julianday(tracker_orm.date)
-                        - func.julianday(tracker_query.reference_date)
-                    )
-                    >= tracker_query.delay
-                )
+
             tracker_orm = session.exec(query).all()  # type: ignore
             return [
                 Ticker(symbol=t[0], exchange=t[1], source=t[2]) for t in tracker_orm  # type: ignore
@@ -349,3 +361,106 @@ class BearishDb(BearishDbBase):
             if result is None:
                 return None
             return result  # type: ignore
+
+    def _read_sec_companies(self) -> List[str]:
+        query = """SELECT DISTINCT company_name FROM sec;"""
+        return self._read_query(query)["company_name"].tolist()
+
+    def _read_sec_share_data(self, company: str) -> pd.DataFrame:
+        query = f"""WITH max_period_table AS (SELECT MAX(s.period) AS max_period 
+                                          FROM sec AS s 
+                                          WHERE s.company_name = '{company}'),
+                     previous_period_table AS (SELECT MAX(s.period) AS previous_period 
+                                               FROM sec AS s 
+                                               WHERE s.period NOT IN (SELECT max_period FROM max_period_table) 
+                                               AND s.company_name = '{company}'),
+
+                     paired AS (SELECT s.company_name, 
+                                       s.name, 
+                                       s.cusip, 
+                                       p.previous_period, 
+                                       m.max_period, 
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.ticker END)      AS curr_ticker, 
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.value END)       AS curr_value, 
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.shares END)      AS curr_shares, 
+                                       MAX(CASE WHEN s.period = p.previous_period THEN s.value END)  AS prev_value, 
+                                       MAX(CASE WHEN s.period = p.previous_period THEN s.shares END) AS prev_shares 
+                                FROM sec AS s 
+                                         CROSS JOIN max_period_table AS m 
+                                         CROSS JOIN previous_period_table AS p 
+                                WHERE s.company_name = '{company}'
+                                GROUP BY s.company_name, s.cusip)
+                SELECT p.name,
+                       p.curr_ticker                      AS ticker,
+                       p.previous_period,
+                       p.max_period,
+                       p.company_name   ,
+                       SUM(p.prev_value)                  AS prev_total_value,
+                       SUM(p.curr_value)                  AS total_value,
+                       SUM(p.curr_value - p.prev_value)   AS total_increase,
+                       SUM(p.prev_shares)                 AS prev_total_shares,
+                       SUM(p.curr_shares)                 AS total_shares,
+                       SUM(p.curr_shares - p.prev_shares) AS shares_increase
+                FROM paired AS p
+                GROUP BY p.cusip, p.curr_ticker
+                ORDER BY total_increase DESC; """
+        return self._read_query(query)
+
+    def _read_sec_shares(self) -> List[SecShareIncrease]:
+        query = """
+                WITH max_period_table AS (SELECT MAX(s.period) AS max_period \
+                                          FROM sec AS s \
+                                          WHERE s.value IS NOT NULL),
+                     previous_period_table AS (SELECT MAX(s.period) AS previous_period \
+                                               FROM sec AS s \
+                                               WHERE s.value IS NOT NULL \
+                                                 AND s.period NOT IN (SELECT max_period FROM max_period_table)),
+
+                     paired AS (SELECT s.company_name, \
+                                       s.name, \
+                                       s.cusip, \
+                                       p.previous_period, \
+                                       m.max_period, \
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.ticker END)      AS curr_ticker, \
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.value END)       AS curr_value, \
+                                       MAX(CASE WHEN s.period = m.max_period THEN s.shares END)      AS curr_shares, \
+                                       MAX(CASE WHEN s.period = p.previous_period THEN s.value END)  AS prev_value, \
+                                       MAX(CASE WHEN s.period = p.previous_period THEN s.shares END) AS prev_shares \
+                                FROM sec AS s \
+                                         CROSS JOIN max_period_table AS m \
+                                         CROSS JOIN previous_period_table AS p \
+                                WHERE s.value IS NOT NULL \
+                                GROUP BY s.company_name, s.cusip)
+                SELECT p.name,
+                       p.curr_ticker                      AS ticker,
+                       p.previous_period,
+                       p.max_period,
+                       COUNT(DISTINCT p.company_name)     AS occurrences,
+                       SUM(p.prev_value)                  AS prev_total_value,
+                       SUM(p.curr_value)                  AS total_value,
+                       SUM(p.curr_value - p.prev_value)   AS total_increase,
+                       SUM(p.prev_shares)                 AS prev_total_shares,
+                       SUM(p.curr_shares)                 AS total_shares,
+                       SUM(p.curr_shares - p.prev_shares) AS shares_increase
+                FROM paired AS p
+                WHERE p.curr_value IS NOT NULL
+                  AND p.prev_value IS NOT NULL
+                GROUP BY p.cusip, p.curr_ticker
+                ORDER BY total_increase DESC; \
+                """
+        data = self._read_query(query)
+        return [
+            SecShareIncrease.model_validate(r) for r in data.to_dict(orient="records")
+        ]
+
+    def _write_sec_shares(self, sec_shares: List["SecShareIncrease"]) -> None:
+
+        with Session(self._engine) as session:
+            data = [serie.model_dump() for serie in sec_shares]
+            chunks = batch(data, BATCH_SIZE)
+            for chunk in chunks:
+                stmt = (
+                    insert(SecShareIncreaseORM).prefix_with("OR REPLACE").values(chunk)
+                )
+                session.exec(stmt)  # type: ignore
+            session.commit()
