@@ -19,6 +19,7 @@ from bearish.models.financials.metrics import (
     QuarterlyFinancialMetrics,
 )
 from bearish.models.price.price import Price
+from bearish.models.sec.sec import Sec, SecShareIncrease
 
 
 class BaseBearishTable(SQLModel):
@@ -78,6 +79,13 @@ class PriceIndexORM(SQLModel, Price, table=True):  # type: ignore
     source: str = Field(primary_key=True, index=True)  # type: ignore
 
 
+class PriceEtfORM(SQLModel, Price, table=True):  # type: ignore
+    __tablename__ = "priceetf"
+    date: datetime = Field(primary_key=True, index=True)
+    symbol: str = Field(primary_key=True, index=True)
+    source: str = Field(primary_key=True, index=True)  # type: ignore
+
+
 class FinancialMetricsORM(BaseFinancials, FinancialMetrics, table=True):  # type: ignore
     __tablename__ = "financialmetrics"
 
@@ -123,3 +131,18 @@ class FinancialsTrackerORM(SQLModel, FinancialsTracker, table=True):
     __table_args__ = {"sqlite_autoincrement": True}
     source: str = Field(index=True, primary_key=True)
     symbol: str = Field(index=True, primary_key=True)
+
+
+class SecORM(SQLModel, Sec, table=True):
+    __tablename__ = "sec"
+    __table_args__ = {"sqlite_autoincrement": True}
+    name: str = Field(index=True, primary_key=True)
+    source: str = Field(index=True, primary_key=True)
+    period: str = Field(index=True, primary_key=True)
+    filed_date: str = Field(index=True, primary_key=True)
+
+
+class SecShareIncreaseORM(SQLModel, SecShareIncrease, table=True):
+    __tablename__ = "secshareincrease"
+    __table_args__ = {"sqlite_autoincrement": True}
+    ticker: str = Field(index=True, primary_key=True)
