@@ -21,6 +21,7 @@ from bearish.models.financials.base import Financials
 from bearish.models.financials.earnings_date import EarningsDate
 from bearish.models.price.price import Price
 from bearish.models.query.query import AssetQuery
+from bearish.models.sec.sec import Sec, SecShareIncrease
 from bearish.utils.utils import observability
 
 
@@ -42,6 +43,22 @@ class BearishDbBase(BaseModel):
     ) -> None:
         return self._write_series(series, table=table)
 
+    @validate_call
+    def write_sec(self, secs: List[Sec]) -> None:
+        return self._write_sec(secs)
+
+    @validate_call
+    def read_sec(self, ticker: str) -> List[Sec]:
+        return self._read_sec(ticker)
+
+    @validate_call
+    def read_sec_shares(self) -> List[SecShareIncrease]:
+        return self._read_sec_shares()
+
+    @validate_call
+    def write_sec_shares(self, sec_shares: List[SecShareIncrease]) -> None:
+        return self._write_sec_shares(sec_shares)
+
     @observability
     @validate_call
     def write_financials(self, financials: List[Financials]) -> None:
@@ -53,6 +70,14 @@ class BearishDbBase(BaseModel):
     ) -> List[Price]:
         return self._read_series(query, months, table=table)
 
+    @validate_call
+    def read_sec_companies(self) -> List[str]:
+        return self._read_sec_companies()
+
+    @validate_call
+    def read_sec_share_data(self, company: str) -> pd.DataFrame:
+        return self._read_sec_share_data(company)
+
     @validate_call
     def read_financials(self, query: AssetQuery) -> Financials:
         return self._read_financials(query)
@@ -101,6 +126,21 @@ class BearishDbBase(BaseModel):
         self, series: List[Price], table: Optional[Type[SQLModel]] = None
     ) -> None: ...
 
+    @abc.abstractmethod
+    def _write_sec(self, secs: List[Sec]) -> None: ...
+
+    @abc.abstractmethod
+    def _read_sec(self, ticker: str) -> List[Sec]: ...
+
+    @abc.abstractmethod
+    def _read_sec_shares(self) -> List[SecShareIncrease]: ...
+    @abc.abstractmethod
+    def _read_sec_companies(self) -> List[str]: ...
+
+    @abc.abstractmethod
+    def _read_sec_share_data(self, company: str) -> pd.DataFrame: ...
+    @abc.abstractmethod
+    def _write_sec_shares(self, sec_shares: List[SecShareIncrease]) -> None: ...
     @abc.abstractmethod
     def _write_financials(self, financials: List[Financials]) -> None: ...
 
