@@ -18,7 +18,7 @@ from rich.console import Console
 from sqlmodel import SQLModel
 
 from bearish.database.crud import BearishDb
-from bearish.database.schemas import PriceIndexORM
+from bearish.database.schemas import PriceIndexORM, PriceEtfORM
 from bearish.exceptions import InvalidApiKeyError, LimitApiKeyReachedError
 from bearish.exchanges.exchanges import (
     Countries,
@@ -35,6 +35,7 @@ from bearish.models.financials.base import Financials
 from bearish.models.price.price import Price
 from bearish.models.price.prices import Prices
 from bearish.models.query.query import AssetQuery, Symbols
+from bearish.models.sec.sec import Secs
 from bearish.sources.base import AbstractSource
 from bearish.sources.financedatabase import FinanceDatabaseSource
 from bearish.sources.financial_modelling_prep import FmpAssetsSource, FmpSource
@@ -80,7 +81,8 @@ class Bearish(BaseModel):
     model_config = ConfigDict(extra="forbid")
     path: Path
     auto_migration: bool = True
-    batch_size: int = Field(default=250)
+    batch_size: int = Field(default=100)
+    pause: int = Field(default=60)
     api_keys: SourceApiKeys = Field(default_factory=SourceApiKeys)
     _bearish_db: BearishDbBase = PrivateAttr()
     exchanges: Exchanges = Field(default_factory=exchanges_factory)
@@ -119,13 +121,14 @@ class Bearish(BaseModel):
             + self.asset_sources
             + self.detailed_asset_sources
         ):
+            source.set_pause(self.pause)
             try:
                 source.set_api_key(
                     self.api_keys.keys.get(
                         source.__source__, os.environ.get(source.__source__.upper())  # type: ignore
                     )
                 )
-            except Exception as e:  # noqa: PERF203
+            except Exception as e:
                 logger.error(
                     f"Invalid API key for {source.__source__}: {e}. It will be removed from sources"
                 )
@@ -138,6 +141,18 @@ class Bearish(BaseModel):
                     if source in sources:
                         sources.remove(source)
 
+    def set_batch_size(self, batch_size: int) -> None:
+        self.batch_size = batch_size
+
+    def set_pause(self, pause: int) -> None:
+        for source in set(
+            self.financials_sources
+            + self.price_sources
+            + self.asset_sources
+            + self.detailed_asset_sources
+        ):
+            source.set_pause(pause)
+
     def get_asset_sources(self) -> List[Sources]:
         return [source.__source__ for source in self.asset_sources]
 
@@ -277,14 +292,14 @@ class Bearish(BaseModel):
             if series_:
                 self._bearish_db.write_series(series_, table=table)
                 if track:
-                    price_date = Prices(prices=series_).get_last_date()
+                    prices_date = Prices(prices=series_)
                     self._bearish_db.write_trackers(
                         [
                             PriceTracker(
                                 symbol=t.symbol,
                                 source=source.__source__,
                                 exchange=t.exchange,
-                                date=price_date,
+                                date=prices_date.ticker_date(t.symbol),
                             )
                             for t in chunk
                         ]
@@ -339,6 +354,22 @@ class Bearish(BaseModel):
             track=False,
         )
 
+    def get_prices_etf(
+        self, series_length: SeriesLength = "max", limit: Optional[int] = None
+    ) -> List[str]:
+        query_etfs = "SELECT DISTINCT symbol from etf;"
+        etf_symbols = self._bearish_db.read_query(query_etfs)["symbol"].tolist()
+        if limit:
+            etf_symbols = etf_symbols[:limit]
+        self.write_many_series(
+            [Ticker(symbol=symbol) for symbol in etf_symbols],
+            series_length,
+            apply_filter=False,
+            table=PriceEtfORM,
+            track=False,
+        )
+        return etf_symbols
+
     def _update(
         self,
         tracker_type: Union[Type[PriceTracker], Type[FinancialsTracker]],
@@ -355,17 +386,21 @@ class Bearish(BaseModel):
             tickers = [t for t in tickers if t.symbol in symbols]
         write_function(tickers)
 
-    def update_prices(
+    def update_prices(  # noqa: PLR0913
         self,
         symbols: Optional[List[str]] = None,
         reference_date: Optional[datetime.date] = None,
         delay: int = 1,
         series_length: SeriesLength = "1mo",
+        batch_size: int = 100,
+        pause: int = 60,
     ) -> None:
         def write_function(tickers: List[Ticker]) -> None:
             logger.debug(f"Updating prices for {len(tickers)} tickers")
-            self.write_many_series(tickers, series_length)
+            self.write_many_series(tickers, series_length, apply_filter=False)
 
+        self.set_batch_size(batch_size)
+        self.set_pause(pause)
         self._update(
             PriceTracker,
             write_function,
@@ -393,13 +428,16 @@ class Bearish(BaseModel):
 
 
 @app.command()
-def run(
+def run(  # noqa: PLR0913
     path: Path,
     countries: Annotated[List[CountriesEnum], typer.Argument()],
     filters: Optional[str] = None,
     api_keys: Optional[Path] = None,
+    etf: bool = True,
+    index: bool = True,
+    sec: bool = True,
+    financials: bool = True,
 ) -> None:
-
     console.log(
         f"Fetching assets to database for countries: {countries}, with filters: {filters}",
     )
@@ -413,12 +451,22 @@ def run(
     with console.status("[bold green]Fetching Price data..."):
         bearish.get_prices(filter)
         console.log("[bold][red]Price downloaded!")
-    with console.status("[bold green]Fetching Price index..."):
-        bearish.get_prices_index()
-        console.log("[bold][red]Price index downloaded!")
-    with console.status("[bold green]Fetching Financial data..."):
-        bearish.get_financials(filter)
-        console.log("[bold][red]Financial downloaded!")
+    if index:
+        with console.status("[bold green]Fetching Price index..."):
+            bearish.get_prices_index()
+            console.log("[bold][red]Price index downloaded!")
+    if etf:
+        with console.status("[bold green]Fetching Etf price..."):
+            bearish.get_prices_etf()
+            console.log("[bold][red]Price etf downloaded!")
+    if sec:
+        with console.status("[bold green]Fetching SEC data..."):
+            Secs.upload(bearish._bearish_db)  # type: ignore
+            console.log("[bold][red]SEC data downloaded!")
+    if financials:
+        with console.status("[bold green]Fetching Financial data..."):
+            bearish.get_financials(filter)
+            console.log("[bold][red]Financial downloaded!")
 
 
 @app.command()
@@ -475,8 +523,23 @@ def prices(
 
 
 @app.command()
-def update(
+def sec(
     path: Path,
+    api_keys: Optional[Path] = None,
+) -> None:
+    with console.status("[bold green]Fetching SEC data..."):
+        source_api_keys = SourceApiKeys.from_file(api_keys)
+        bearish = Bearish(path=path, api_keys=source_api_keys)
+        Secs.upload(bearish._bearish_db)  # type: ignore
+
+
+@app.command()
+def update(  # noqa: PLR0913
+    path: Path,
+    etf: bool = True,
+    index: bool = True,
+    sec: bool = True,
+    financials: bool = True,
     symbols: Optional[List[str]] = None,
     api_keys: Optional[Path] = None,
     series_length: str = "1mo",
@@ -484,8 +547,14 @@ def update(
     source_api_keys = SourceApiKeys.from_file(api_keys)
     bearish = Bearish(path=path, api_keys=source_api_keys)
     bearish.update_prices(symbols, series_length=series_length)  # type: ignore
-    bearish.get_prices_index(series_length=series_length)  # type: ignore
-    bearish.update_financials(symbols)
+    if index:
+        bearish.get_prices_index(series_length=series_length)  # type: ignore
+    if etf:
+        bearish.get_prices_etf(series_length=series_length)  # type: ignore
+    if sec:
+        Secs.upload(bearish._bearish_db)  # type: ignore
+    if financials:
+        bearish.update_financials(symbols)
 
 
 if __name__ == "__main__":
