@@ -7,7 +7,12 @@ from typing import List, Optional, Dict, Any, Callable, cast
 import pandas as pd
 import yfinance as yf  # type: ignore
 from pydantic import BaseModel, Field
-from tenacity import retry, stop_after_attempt, wait_fixed, wait_exponential
+from tenacity import (
+    retry,
+    stop_after_attempt,
+    wait_fixed,
+    wait_exponential,
+)
 
 from bearish.exchanges.exchanges import Countries
 from bearish.models.assets.etfs import Etf
@@ -425,10 +430,26 @@ class yFinanceSource(YfinanceBase, AbstractSource):
         data = yf.download(
             tickers, period=type, group_by="ticker", auto_adjust=True, timeout=60
         )
-        if any(data[(ticker, "Close")].empty for ticker in tickers):
-            data = yf.download(
-                tickers, period=type, group_by="ticker", auto_adjust=True, timeout=60
+        missing_tickers = [
+            ticker for ticker in tickers if data[(ticker, "Close")].dropna().empty
+        ]
+        if missing_tickers:
+            time.sleep(self.pause)
+            valid_tickers = list(set(tickers).difference(set(missing_tickers)))
+            data = data[valid_tickers]
+            logger.warning(f"Missing tickers: {missing_tickers}")
+            print(f"Missing tickers: {missing_tickers}")
+            data_missing = yf.download(
+                missing_tickers,
+                period=type,
+                group_by="ticker",
+                auto_adjust=True,
+                timeout=60,
             )
+            if not data_missing.empty:
+                data = pd.concat([data, data_missing], axis=1)
+            else:
+                print("None of the missing tickers where found")
 
         records_final = []
         for ticker in tickers:
@@ -453,4 +474,5 @@ class yFinanceSource(YfinanceBase, AbstractSource):
                     )
             except Exception as e:  # noqa: PERF203
                 logger.error(f"Error reading series for {ticker}: {e}")
+        time.sleep(self.pause)
         return records_final
